EtherCAT.Simulator.Slave.Definition (ethercat v0.4.2)

Copy Markdown View Source

Public authored definition for a simulated EtherCAT slave.

A definition describes the high-level device identity, process-data layout, mailbox/object-dictionary capabilities, and behavior module. Derived low-level ESC state such as EEPROM contents and register memory is hydrated internally by the simulator runtime and is not part of this public type.

Summary

Types

Mailbox SM layout declared by the simulated device.

t()

High-level, authored simulator device definition.

Types

mailbox_config()

@type mailbox_config() :: %{
  recv_offset: non_neg_integer(),
  recv_size: non_neg_integer(),
  send_offset: non_neg_integer(),
  send_size: non_neg_integer()
}

Mailbox SM layout declared by the simulated device.

t()

@opaque t()

High-level, authored simulator device definition.

Functions

build(profile, opts \\ [])

@spec build(
  atom(),
  keyword()
) :: t()

from_driver(driver, config, adapter)

@spec from_driver(module(), map(), module()) :: t()